Struct cvar::Context
[−]
[src]
pub struct Context<'a> {
pub args: &'a str,
pub write: &'a mut Write,
// some fields omitted
}Invocation context.
Provides a place to pass parameters through to the action callback.
Fields
args: &'a str
The command arguments.
There are no extra constraints on the formatting, it is passed through to the underlying action.
write: &'a mut Write
A console-like interface.
Allows the action to let the world know what it has to say.