Struct cvar::List [] [src]

pub struct List<'a, N, D> where N: Borrow<str>, D: Borrow<str> {
    // some fields omitted
}

List instance.

The Name and Description types allow abstracting over &'static str, &'a str and String. This supports dynamic cvars while only paying for what you need.

Methods

impl<'a, N, D> List<'a, N, D> where N: Borrow<str>, D: Borrow<str>
[src]

fn new(name: N, desc: D, visit: &'a IVisit) -> List<'a, N, D>

Creates a new List.

Given a name, description and visitor to access its children.